/*
 * 创建表结构
 */

CREATE TABLE rtAvailableOut (
  outId	int(11) NOT NULL,
  accountId int(11) NOT NULL,
  PRIMARY KEY (outId,accountId),
  INDEX rtAvailableOut_outId_idx (outId),
  INDEX rtAvailableOut_accountId_idx (accountId)
--  FOREIGN KEY (accountId) REFERENCES rtSipAccount (id),
--  FOREIGN KEY (outId) REFERENCES rtOutNo (id),
) COMMENT='可用的出局';

CREATE TABLE rtCallLog (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  userName VARCHAR(45) NOT NULL COMMENT '用户账号',
  callId VARCHAR(50) NOT NULL COMMENT '通话ID',
  callType int(11) NOT NULL COMMENT '通话类型：\n1：呼出\n2：已接\n3：未接',
  contactPhone varchar(15) NOT NULL COMMENT '联系人电话号码',
  contactName varchar(45) NOT NULL COMMENT '联系人名称',
  talkTime datetime NOT NULL COMMENT '通话时间',
  talkTimeLength int(11) NOT NULL COMMENT '通话时长',
  talkDescription varchar(1000) NOT NULL COMMENT '通话内容描述',
  audioFile varchar(256) COMMENT '录音文件名称',
  audioFileSize int(11) COMMENT '录音文件大小',
  sipServer varchar(45) COMMENT '语音交换机地址',
  sipUserName varchar(45) COMMENT '注册到交换机上的用户名',
  sipExt varchar(45) COMMENT '注册到交换机的分机号',
  eventId VARCHAR(45) COMMENT '业务事件唯一标识',
  PRIMARY KEY (id),
  UNIQUE KEY eventId_UNIQUE (eventId)
) COMMENT='电话通话日志';

CREATE TABLE rtCommonContact (
  employeeId bigint(20) NOT NULL,
  contactId bigint(20) NOT NULL,
  contactType int(11) NOT NULL,
  PRIMARY KEY (employeeId,contactId,contactType)
) COMMENT='用户的常用联系人';

CREATE TABLE rtConversationLog (
  id bigint(20) NOT NULL AUTO_INCREMENT,
--  senderId bigint(20) COMMENT '发送人账号',
  senderJid varchar(45),
  senderNickName varchar(45) COMMENT '发送人昵称 ',
  sendTime datetime NOT NULL COMMENT '日志记录时间',
--  receiverId bigint(20) COMMENT '接收人',
  receiverJid varchar(45) COMMENT '接收人JID',
  receiverNickName varchar(45) COMMENT '接收人昵称',
  messageText text NOT NULL COMMENT '消息正文',
  messageBytes varbinary(1000) COMMENT '消息原始内容',
  PRIMARY KEY (id)
) COMMENT='即时消息会话日志';

CREATE TABLE rtDepartment (
  id bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID	',
  name varchar(45) NOT NULL COMMENT '部门名称',
  seqNo int(11) COMMENT '显示顺序',
  remark varchar(45) COMMENT '部门简介',
  email varchar(45) COMMENT '电子邮件地址',
  fax varchar(45) COMMENT '传真号码',
  telephone varchar(45) COMMENT '办公电话号码',
  telephoneExt varchar(45) COMMENT '办公电话分机号码',
  parentId bigint(20) COMMENT '上级部门ID',
  coding varchar(200) NOT NULL COMMENT '节点编码，便于树节点运算。',
  areaCode VARCHAR(10) COMMENT '区号',
  PRIMARY KEY (id)
) COMMENT='部门';

CREATE TABLE rtEmployee (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  email varchar(45) COMMENT '电子邮件地址',
  fax varchar(45) COMMENT '传真号码',
  telephone varchar(45) COMMENT '办公电话号码',
  name varchar(45) NOT NULL COMMENT '姓名',
  telephoneExt varchar(45) COMMENT '办公电话分机号码',
  mobile varchar(45) COMMENT '手机号码',
  departmentId bigint(20) COMMENT '所属部门ID',
  birthday date COMMENT '出生日期',
  sex int(11) COMMENT '性别',
  username varchar(32) COMMENT '用户名',
  created datetime NOT NULL COMMENT '创建时间',
  updated datetime NOT NULL COMMENT '最近修改时间',
  birthplace varchar(45) COMMENT '籍贯，出生地。',
  password varchar(255),
  photo varchar(45) COMMENT '照片（大头像）',
  sipAccountId int(11),
  photoBinval mediumtext COMMENT '编码后的照片',
  PRIMARY KEY (id),
  UNIQUE KEY username_UNIQUE (username),
  UNIQUE KEY sipAccountId (sipAccountId),
  INDEX rtEmployee_departmentId_idx (departmentId)
--  FOREIGN KEY (departmentId) REFERENCES rtDepartment (id),
) COMMENT='员工';

CREATE TABLE rtEmployeePosition (
  positionId bigint(20) NOT NULL,
  employeeId bigint(20) NOT NULL,
  PRIMARY KEY (positionId,employeeId),
  INDEX rtEmployeePosition_positionId_idx (positionId),
--  FOREIGN KEY (positionId) REFERENCES rtPosition (id),
  INDEX rtEmployeePosition_employeeId_idx (employeeId)
--  FOREIGN KEY (employeeId) REFERENCES rtEmployee (id),
) COMMENT='员工与岗位对应关联,一个员工可以兼多岗.';

CREATE TABLE rtFax (
  no varchar(20) NOT NULL,
  PRIMARY KEY (no)
);

CREATE TABLE rtFunction (
  coding varchar(50) NOT NULL COMMENT '功能编码',
  description varchar(100) COMMENT '功能描述',
  PRIMARY KEY (coding)
) COMMENT='功能表';

CREATE TABLE rtGroupConversationLog (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  senderId bigint(20) COMMENT '发送人账号',
  senderJid varchar(45),
  senderNickName varchar(45) NOT NULL COMMENT '发送人昵称',
  sendTime datetime NOT NULL COMMENT '日志记录时间',
  groupId bigint(20) NOT NULL COMMENT '接收人',
  groupJid varchar(45) COMMENT '接收人JID',
  groupName varchar(45) COMMENT '接收人昵称',
  messageText text NOT NULL COMMENT '消息正文',
  messageBytes varbinary(1000) COMMENT '消息原始内容',
  PRIMARY KEY (id)
) COMMENT='即时消息会话日志';

CREATE TABLE rtIncomingFaxLog (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  senderName varchar(45) COMMENT '发件人名称',
  fromFax varchar(45) COMMENT '发件的传真号码',
  receiveTime datetime,
  contentFile varchar(256),
  PRIMARY KEY (id)
) COMMENT='收到的传真';

CREATE TABLE rtLastContact (
  employeeId bigint(20) NOT NULL,
  contactId bigint(20) NOT NULL,
  contactType int(11) NOT NULL,
  PRIMARY KEY (employeeId,contactId,contactType)
) COMMENT='用户的最近联系人';

CREATE TABLE rtMobileMemory (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  mobile varchar(45) NOT NULL COMMENT '手机号码',
  server varchar(45) NOT NULL COMMENT '落地语音交换机',
  local tinyint(1) NOT NULL COMMENT '是否本地号码',
  lastCallTime datetime NOT NULL COMMENT '最后拨打时间',
  PRIMARY KEY (id)
) COMMENT='拨打手机的记忆';

CREATE TABLE rtOut (
  id int(11) NOT NULL AUTO_INCREMENT,
  description varchar(100),
  serverId int(11) NOT NULL,
  no int(11) NOT NULL,
  mobile VARCHAR(20) COMMENT '手机号',
  PRIMARY KEY (id),
  INDEX rtOut_serverId_idx (serverId)
--  FOREIGN KEY (serverId) REFERENCES rtSipServer (id)
) COMMENT='出局';

CREATE TABLE rtOutGoingFaxLog (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  senderId bigint(20) COMMENT '发送者',
  recipientFax varchar(45) COMMENT '收件的传真',
  recipientName varchar(45) COMMENT '收件人名称',
  sendTime datetime COMMENT '发送时间',
  contentFile varchar(256) COMMENT '内容文件',
  outgoingFax varchar(45) COMMENT '发件的传真',
  PRIMARY KEY (id)
) COMMENT='发出的传真';


CREATE TABLE rtPosition (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  name varchar(45),
  remark varchar(45) COMMENT '岗位描述',
  level int(11) NOT NULL COMMENT '岗位级别',
  PRIMARY KEY (id)
) COMMENT='岗位';

CREATE TABLE rtRole (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  name varchar(45) NOT NULL,
  remark varchar(45),
  PRIMARY KEY (id),
  UNIQUE KEY name_UNIQUE (name)
) COMMENT='角色';

CREATE TABLE rtRoleDepartment (
  roleId bigint(20) NOT NULL COMMENT '角色ID',
  departmentId bigint(20) NOT NULL COMMENT '部门ID',
  PRIMARY KEY (roleId,departmentId),
  INDEX rtRoleDepartment_roleId_idx (roleId),
--  FOREIGN KEY (roleId) REFERENCES rtRole (id)
  INDEX rtRoleDepartment_departmentId_idx (departmentId)
--  FOREIGN KEY (departmentId) REFERENCES rtDepartment (id)
) COMMENT='角色能访问的部门';

CREATE TABLE rtRoleFunctionPermission (
  roleId bigint(20) NOT NULL COMMENT '角色ID',
  functionCoding varchar(45) NOT NULL COMMENT '功能项编码',
  PRIMARY KEY (roleId,functionCoding),
  INDEX rtRoleFunctionPermission_roleId_idx (roleId),
--  FOREIGN KEY (roleId) REFERENCES rtRole (id),
  INDEX rtRoleFunctionPermission_functionCoding_idx (functionCoding)
--  FOREIGN KEY (functionCoding) REFERENCES rtFunction (coding),
) COMMENT='角色所具有的功能权限';

CREATE TABLE rtRolePosition (
  roleId bigint(20) NOT NULL,
  positionId bigint(20) NOT NULL,
  PRIMARY KEY (roleId,positionId),
  INDEX rtRolePosition_roleId_idx (roleId),
--  FOREIGN KEY (roleId) REFERENCES rtRole (id),
  INDEX rtRolePosition_positionId_idx (positionId)
--  FOREIGN KEY (positionId) REFERENCES rtPosition (id),
) COMMENT='角色所能访问的岗位.';

CREATE TABLE rtSipAccount (
  id int(11) NOT NULL AUTO_INCREMENT,
  userName varchar(45) NOT NULL COMMENT '账号',
  password varchar(45) NOT NULL COMMENT '密码',
  ext int(11) NOT NULL COMMENT '分机号',
  remark varchar(100) COMMENT '备注',
  serverId int(11) NOT NULL,
  PRIMARY KEY (id),
  INDEX rtSipAccount_serverId_idx (serverId)
--  FOREIGN KEY (serverId) REFERENCES rtSipServer (id)
);

CREATE TABLE rtSipServer (
  id int(11) NOT NULL AUTO_INCREMENT,
  address varchar(45) NOT NULL COMMENT 'IP地址',
  address1 varchar(45) COMMENT 'IP地址',
  port int(11) NOT NULL COMMENT '端口',
  description varchar(100) COMMENT '描述',
  PRIMARY KEY (id),
  UNIQUE KEY address_UNIQUE (address)
) COMMENT='可用的语音交换机';

CREATE TABLE rtSmsLog (
  id bigint(20) NOT NULL AUTO_INCREMENT,
--  senderId bigint(20) NOT NULL COMMENT '发送人ID',
  messageContent varchar(1000) NOT NULL COMMENT '短信内容',
  logTime datetime NOT NULL COMMENT '发送时间',
  count int(11) NOT NULL COMMENT '接收人数',
  receivers varchar(3000) NOT NULL COMMENT '所有接收人',
  channel varchar(45) NOT NULL COMMENT '通过什么通道发出去的',
  account varchar(45) NOT NULL COMMENT '账号唯一标识',
  result tinyint(1) NOT NULL COMMENT '发送结果:1成功/0失败',
  errMsg varchar(100) COMMENT '错误消息',
  senderUserName varchar(50) NOT NULL COMMENT '发送人的账号名',
  PRIMARY KEY (id)
) COMMENT='短信日志';

CREATE TABLE rtUserRole (
  userId bigint(20) NOT NULL,
  roleId bigint(20) NOT NULL,
  PRIMARY KEY (userId,roleId),
  INDEX rtUserRole_userId_idx (userId),
--  FOREIGN KEY (userId) REFERENCES rtEmployee(id),
  INDEX rtUserRole_roleId_idx (roleId)
--  FOREIGN KEY (roleId) REFERENCES rtRole(id),
) COMMENT='用户角色关联表';

CREATE TABLE rtCluster (
  id INT NOT NULL AUTO_INCREMENT,
  Description VARCHAR(100),
  PRIMARY KEY (id) 
) COMMENT='手机集群网' ;


CREATE TABLE rtMobileCluster (
  mobile VARCHAR(20) NOT NULL ,
  clusterId INT NOT NULL ,
  PRIMARY KEY (mobile) ,
  INDEX rtMobileCluster_clusterId_idx (clusterId)
) COMMENT='手机与集群网关系表';

CREATE TABLE rtUserSetting (
  userName VARCHAR(45) NOT NULL ,
  sKey VARCHAR(45) NOT NULL ,
  sValue VARCHAR(45) NOT NULL ,
  PRIMARY KEY (userName, sKey) 
) COMMENT = '用户设置';

CREATE  TABLE rtOfflineFile (
  sid VARCHAR(45) NOT NULL ,
  fileName VARCHAR(256) NOT NULL COMMENT '文件名称' ,
  fileSize INT NOT NULL COMMENT '文件大小（K）' ,
  initiator VARCHAR(45) NOT NULL COMMENT '初始方JID' ,
  target VARCHAR(45) NOT NULL COMMENT '目标方JID' ,
  sendTime DATETIME NOT NULL COMMENT '发送时间' ,
  tag VARCHAR(45) NULL COMMENT '特殊标记' ,
  PRIMARY KEY (sid) 
) COMMENT = '离线文件' ;


CREATE  TABLE rtCompanyGroup (
  id BIGINT NOT NULL AUTO_INCREMENT ,
  name VARCHAR(45) NOT NULL COMMENT '名称' ,
  description VARCHAR(100) NULL COMMENT '描述' ,
  PRIMARY KEY (id) ,
  UNIQUE INDEX name_UNIQUE (name ASC) 
) COMMENT = '企业分组\n' ;

CREATE  TABLE rtPublicContactGroup (
  id BIGINT NOT NULL AUTO_INCREMENT ,
  name VARCHAR(45) NOT NULL ,
  description VARCHAR(100) NULL ,
  PRIMARY KEY (id) ,
  UNIQUE INDEX name_UNIQUE (name ASC) 
) COMMENT = '联系人分组\n' ;

CREATE  TABLE rtPublicContact (
  id BIGINT NOT NULL AUTO_INCREMENT ,
  name VARCHAR(45) NOT NULL ,
  email VARCHAR(45) NULL ,
  fax VARCHAR(45) NULL ,
  telephone VARCHAR(45) NULL ,
  mobile VARCHAR(45) NULL ,
  position VARCHAR(45) NULL COMMENT '职位' ,
  companyId BIGINT NULL ,
  sex INT NULL COMMENT '性别' ,
  birthday DATE NULL COMMENT '生日' ,
  birthplace VARCHAR(45) NULL COMMENT '籍贯' ,
  created DATETIME NULL COMMENT '创建时间' ,
  creator VARCHAR(45) NULL ,
  updated DATETIME NULL ,
  updator VARCHAR(45) NULL ,
  restriction INT NOT NULL DEFAULT 0 COMMENT '限制：\n0:无限制\n1:从组继承\n2:个别限制' ,
  companyName VARCHAR(100) COMMENT '公司名称' ,
  description VARCHAR(1000) NULL ,
  PRIMARY KEY (id) 
) COMMENT = '客户联系人' ;

CREATE  TABLE rtCompany (
  id BIGINT NOT NULL AUTO_INCREMENT ,
  email VARCHAR(45) NULL COMMENT '电子邮件地址' ,
  fax VARCHAR(45) NULL COMMENT '传真号码' ,
  telephone VARCHAR(45) NULL COMMENT '电话号码' ,
  name VARCHAR(100) NOT NULL COMMENT '企业名称' ,
  website VARCHAR(45) NULL COMMENT '企业门户网址' ,
  creator VARCHAR(45) NOT NULL COMMENT '创建人的userName' ,
  created DATETIME NOT NULL COMMENT '创建时间' ,
  updated DATETIME NOT NULL COMMENT '最近修改时间' ,
  description VARCHAR(1000) NULL COMMENT '简介' ,
  address VARCHAR(100) NULL COMMENT '地址' ,
  restriction INT NOT NULL DEFAULT 0 COMMENT '限制：\n0:无限制\n1:按组限制\n2:个别限制' ,
  PRIMARY KEY (id) ,
  UNIQUE INDEX name_UNIQUE (name ASC) 
) COMMENT = '企业' ;

CREATE  TABLE rtCompanyBelongGroup (
  companyId BIGINT NOT NULL ,
  groupId BIGINT NOT NULL ,
  PRIMARY KEY (companyId, groupId) ,
  INDEX fk_CompanyBelongGroup_rtCompany1 (companyId ASC) ,
  INDEX fk_CompanyBelongGroup_rtCompanyGroup1 (groupId ASC)
);

CREATE  TABLE rtPublicContactBelongGroup (
  contactId BIGINT NOT NULL ,
  groupId BIGINT NOT NULL ,
  PRIMARY KEY (contactId, groupId) ,
  INDEX fk_ContactBelongGroup_rtContactGroup1 (groupId ASC) ,
  INDEX fk_ContactBelongGroup_rtContact1 (contactId ASC)
);

CREATE  TABLE rtPublicContactGroupUser (
  userName VARCHAR(45) NOT NULL COMMENT '用户（员工）ID' ,
  groupId BIGINT NOT NULL COMMENT '客户ID' ,
  weight INT NOT NULL COMMENT '使用权重' ,
  PRIMARY KEY (userName, groupId) ,
  INDEX fk_rtContactGroupUser_rtContactGroup1 (groupId ASC)
) COMMENT = '客户的使用关系' ;

CREATE  TABLE rtCompanyGroupUser (
  userName VARCHAR(45) NOT NULL COMMENT '用户（员工）ID' ,
  groupId BIGINT NOT NULL COMMENT '客户ID' ,
  weight INT NOT NULL COMMENT '使用权重\n素数算法：\n3：维护权限\n5：授权权限\n7：使用权限' ,
  PRIMARY KEY (userName, groupId) ,
  INDEX fk_rtCompanyGroupUser_rtCompanyGroup1 (groupId ASC)
) COMMENT = '客户的使用关系' ;

CREATE  TABLE rtPrivateContact (
  id BIGINT NOT NULL AUTO_INCREMENT ,
  name VARCHAR(45) NOT NULL ,
  email VARCHAR(45) NULL ,
  fax VARCHAR(45) NULL ,
  telephone VARCHAR(45) NULL ,
  mobile VARCHAR(45) NULL ,
  position VARCHAR(45) NULL COMMENT '职位' ,
  sex INT NULL COMMENT '性别' ,
  birthday DATETIME NULL COMMENT '生日' ,
  birthplace VARCHAR(45) NULL COMMENT '籍贯' ,
  created DATETIME NULL COMMENT '创建时间' ,
  creator VARCHAR(45) NULL ,
  userName VARCHAR(45) NULL COMMENT '属于哪个用户的私有联系人' ,
  shareContactId BIGINT NULL COMMENT '分享出去的公共联系人ID' ,
  companyName VARCHAR(100) COMMENT '公司名称' ,
  description VARCHAR(1000) NULL COMMENT '备注/描述' ,
  PRIMARY KEY (id) 
) COMMENT = '客户联系人' ;

CREATE  TABLE rtPrivateContactGroup (
  id BIGINT NOT NULL AUTO_INCREMENT ,
  name VARCHAR(45) NOT NULL ,
  description VARCHAR(100) NULL ,
  userName VARCHAR(45) NOT NULL ,
  PRIMARY KEY (id) ,
  UNIQUE INDEX name_UNIQUE (name ASC) 
) COMMENT = '私有联系人分组\n' ;

CREATE  TABLE rtPrivateContactBelongGroup (
  contactId BIGINT NOT NULL ,
  groupId BIGINT NOT NULL ,
  PRIMARY KEY (contactId, groupId) ,
  INDEX fk_rtPrivateContactBelongGroup_rtPrivateContact1 (contactId ASC) ,
  INDEX fk_rtPrivateContactBelongGroup_rtPrivateContactGroup1 (groupId ASC) 
);




/* 
 * 修改表结构
 */
ALTER TABLE ofVcard ADD signature varchar(100) COMMENT '个性签名';

/*
 * 初始化数据
 */

-- 创建管理员账号
INSERT INTO rtEmployee (userName, password, name, email, created, updated)
	VALUES ('admin', 'e10adc3949ba59abbe56e057f20f883e', '系统管理员', 'admin@example.com', NOW(), NOW());

-- 创建部门群聊所用的会议室
INSERT INTO `ofmucroom` 
	(`serviceID`, `roomID`, `creationDate`, `modificationDate`, `name`, `naturalName`, `description`, `lockedDate`, `emptyDate`, `canChangeSubject`, `maxUsers`, `publicRoom`, `moderated`, `membersOnly`, `canInvite`, `roomPassword`, `canDiscoverJID`, `logEnabled`, `subject`, `rolesToBroadcast`, `useReservedNick`, `canChangeNick`, `canRegister`) 
	VALUES
	(1, 1, '0', '0', 'company', '全公司', '为了建立同事之间的订阅关系而设的特殊房间。', '000000000000000', NULL, 0, 0, 1, 0, 0, 0, NULL, 1, 0, '', 7, 0, 1, 1);

/*
INSERT INTO `ofmucaffiliation` (`roomID`, `jid`, `affiliation`)
	VALUES (1, 'admin@58.252.8.132', 10)
*/

-- 初始化功能列表
INSERT INTO `rtFunction` (`coding`, `description`) VALUES
	('ALLOW_CALL', '允许打电话'),
	('ALLOW_FAX', '允许发传真'),
	('ALLOW_SMS', '允许发短信'),
	('CONTACT_LOG', '查看通讯日志'),
	('CUSTOMER', '管理客户资料'),
	('EMPLOYEE', '管理员工档案'),
	('ROLE', '配置角色'),
	('STRUCTURE', '配置组织架构（包括部门和岗位）'),
	('SYSTEM_PARA', '配置系统参数（包括SIP设置）');
	


