# $Revision: 1650 $
# $Date: 2005-07-20 00:18:17 -0300 (Wed, 20 Jul 2005) $

CREATE TABLE ofUser (
  username              VARCHAR(64)     NOT NULL,
  plainPassword         VARCHAR(32),
  encryptedPassword     VARCHAR(255),
  name                  VARCHAR(100),
  email                 VARCHAR(100),
  creationDate          CHAR(15)        NOT NULL,
  modificationDate      CHAR(15)        NOT NULL,
  PRIMARY KEY (username),
  INDEX ofUser_cDate_idx (creationDate)
) DEFAULT CHARSET=utf8;

CREATE TABLE ofUserProp (
  username              VARCHAR(64)     NOT NULL,
  name                  VARCHAR(100)    NOT NULL,
  propValue             TEXT            NOT NULL,
  PRIMARY KEY (username, name)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofUserFlag (
  username              VARCHAR(64)     NOT NULL,
  name                  VARCHAR(100)    NOT NULL,
  startTime             CHAR(15),
  endTime               CHAR(15),
  PRIMARY KEY (username, name),
  INDEX ofUserFlag_sTime_idx (startTime),
  INDEX ofUserFlag_eTime_idx (endTime)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPrivate (
  username              VARCHAR(64)     NOT NULL,
  name                  VARCHAR(100)    NOT NULL,
  namespace             VARCHAR(200)    NOT NULL,
  privateData           TEXT            NOT NULL,
  PRIMARY KEY (username, name, namespace(100))
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofOffline (
  username              VARCHAR(64)     NOT NULL,
  messageID             BIGINT          NOT NULL,
  creationDate          CHAR(15)        NOT NULL,
  messageSize           INTEGER         NOT NULL,
  stanza                TEXT            NOT NULL,
  PRIMARY KEY (username, messageID)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPresence (
  username              VARCHAR(64)     NOT NULL,
  offlinePresence       TEXT,
  offlineDate           CHAR(15)     NOT NULL,
  PRIMARY KEY (username)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofRoster (
  rosterID              BIGINT          NOT NULL,
  username              VARCHAR(64)     NOT NULL,
  jid                   VARCHAR(255)   NOT NULL,
  sub                   TINYINT         NOT NULL,
  ask                   TINYINT         NOT NULL,
  recv                  TINYINT         NOT NULL,
  nick                  VARCHAR(255),
  PRIMARY KEY (rosterID),
  INDEX ofRoster_unameid_idx (username),
  INDEX ofRoster_jid_idx (jid)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofRosterGroups (
  rosterID              BIGINT          NOT NULL,
  rank                  TINYINT         NOT NULL,
  groupName             VARCHAR(255)    NOT NULL,
  PRIMARY KEY (rosterID, rank),
  INDEX ofRosterGroup_rosterid_idx (rosterID)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofVCard (
  username              VARCHAR(64)     NOT NULL,
  vcard                 MEDIUMTEXT      NOT NULL,
  PRIMARY KEY (username)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofGroup (
  groupName             VARCHAR(50)     NOT NULL,
  description           VARCHAR(255),
  PRIMARY KEY (groupName)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofGroupProp (
  groupName             VARCHAR(50)     NOT NULL,
  name                  VARCHAR(100)    NOT NULL,
  propValue             TEXT            NOT NULL,
  PRIMARY KEY (groupName, name)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofGroupUser (
  groupName             VARCHAR(50)     NOT NULL,
  username              VARCHAR(100)    NOT NULL,
  administrator         TINYINT         NOT NULL,
  PRIMARY KEY (groupName, username, administrator)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofID (
  idType                INTEGER         NOT NULL,
  id                    BIGINT          NOT NULL,
  PRIMARY KEY (idType)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofProperty (
  name        VARCHAR(100)              NOT NULL,
  propValue   TEXT                      NOT NULL,
  PRIMARY KEY (name)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofVersion (
  name     VARCHAR(50)  NOT NULL,
  version  INTEGER  NOT NULL,
  PRIMARY KEY (name)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofExtComponentConf (
  subdomain             VARCHAR(255)    NOT NULL,
  wildcard              TINYINT         NOT NULL,
  secret                VARCHAR(255),
  permission            VARCHAR(10)     NOT NULL,
  PRIMARY KEY (subdomain)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofRemoteServerConf (
  xmppDomain            VARCHAR(255)    NOT NULL,
  remotePort            INTEGER,
  permission            VARCHAR(10)     NOT NULL,
  PRIMARY KEY (xmppDomain)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPrivacyList (
  username              VARCHAR(64)     NOT NULL,
  name                  VARCHAR(100)    NOT NULL,
  isDefault             TINYINT         NOT NULL,
  list                  TEXT            NOT NULL,
  PRIMARY KEY (username, name),
  INDEX ofPrivacyList_default_idx (username, isDefault)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofSASLAuthorized (
  username            VARCHAR(64)   NOT NULL,
  principal           TEXT          NOT NULL,
  PRIMARY KEY (username, principal(200))
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofSecurityAuditLog (
  msgID                 BIGINT          NOT NULL,
  username              VARCHAR(64)     NOT NULL,
  entryStamp            BIGINT          NOT NULL,
  summary               VARCHAR(255)    NOT NULL,
  node                  VARCHAR(255)    NOT NULL,
  details               TEXT,
  PRIMARY KEY (msgID),
  INDEX ofSecurityAuditLog_tstamp_idx (entryStamp),
  INDEX ofSecurityAuditLog_uname_idx (username)
)  DEFAULT CHARSET=utf8;

# MUC Tables

CREATE TABLE ofMucService (
  serviceID           BIGINT        NOT NULL,
  subdomain           VARCHAR(255)  NOT NULL,
  description         VARCHAR(255),
  isHidden            TINYINT       NOT NULL,
  PRIMARY KEY (subdomain),
  INDEX ofMucService_serviceid_idx (serviceID)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofMucServiceProp (
  serviceID           BIGINT        NOT NULL,
  name                VARCHAR(100)  NOT NULL,
  propValue           TEXT          NOT NULL,
  PRIMARY KEY (serviceID, name)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofMucRoom (
  roomID              BIGINT        NOT NULL  AUTO_INCREMENT,
  serviceID           BIGINT        NOT NULL,
  creationDate        CHAR(15)      NOT NULL,
  modificationDate    CHAR(15)      NOT NULL,
  name                VARCHAR(50)   NOT NULL,
  naturalName         VARCHAR(255)  NOT NULL,
  description         VARCHAR(255),
  lockedDate          CHAR(15)      NOT NULL,
  emptyDate           CHAR(15)      NULL,
  canChangeSubject    TINYINT       NOT NULL,
  maxUsers            INTEGER       NOT NULL,
  publicRoom          TINYINT       NOT NULL,
  moderated           TINYINT       NOT NULL,
  membersOnly         TINYINT       NOT NULL,
  canInvite           TINYINT       NOT NULL,
  roomPassword        VARCHAR(50)   NULL,
  canDiscoverJID      TINYINT       NOT NULL,
  logEnabled          TINYINT       NOT NULL,
  subject             VARCHAR(100)  NULL,
  rolesToBroadcast    TINYINT       NOT NULL,
  useReservedNick     TINYINT       NOT NULL,
  canChangeNick       TINYINT       NOT NULL,
  canRegister         TINYINT       NOT NULL,
  PRIMARY KEY (roomID),
  INDEX ofMucRoom_name_idx (name),
  INDEX ofMucRoom_serviceid_idx (serviceID)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofMucRoomProp (
  roomID                BIGINT          NOT NULL,
  name                  VARCHAR(100)    NOT NULL,
  propValue             TEXT            NOT NULL,
  PRIMARY KEY (roomID, name)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofMucAffiliation (
  roomID              BIGINT        NOT NULL,
  jid                 TEXT          NOT NULL,
  affiliation         TINYINT       NOT NULL,
  PRIMARY KEY (roomID,jid(70))
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofMucMember (
  roomID              BIGINT        NOT NULL,
  jid                 TEXT          NOT NULL,
  nickname            VARCHAR(255)  NULL,
  firstName           VARCHAR(100)  NULL,
  lastName            VARCHAR(100)  NULL,
  url                 VARCHAR(100)  NULL,
  email               VARCHAR(100)  NULL,
  faqentry            VARCHAR(100)  NULL,
  PRIMARY KEY (roomID,jid(70))
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofMucConversationLog (
  roomID              BIGINT        NOT NULL,
  sender              TEXT          NOT NULL,
  nickname            VARCHAR(255)  NULL,
  logTime             CHAR(15)      NOT NULL,
  subject             VARCHAR(255)  NULL,
  body                TEXT          NULL,
  INDEX ofMucConversationLog_time_idx (logTime)
)  DEFAULT CHARSET=utf8;

# PubSub Tables

CREATE TABLE ofPubsubNode (
  serviceID           VARCHAR(100)  NOT NULL,
  nodeID              VARCHAR(100)  NOT NULL,
  leaf                TINYINT       NOT NULL,
  creationDate        CHAR(15)      NOT NULL,
  modificationDate    CHAR(15)      NOT NULL,
  parent              VARCHAR(100)  NULL,
  deliverPayloads     TINYINT       NOT NULL,
  maxPayloadSize      INTEGER       NULL,
  persistItems        TINYINT       NULL,
  maxItems            INTEGER       NULL,
  notifyConfigChanges TINYINT       NOT NULL,
  notifyDelete        TINYINT       NOT NULL,
  notifyRetract       TINYINT       NOT NULL,
  presenceBased       TINYINT       NOT NULL,
  sendItemSubscribe   TINYINT       NOT NULL,
  publisherModel      VARCHAR(15)   NOT NULL,
  subscriptionEnabled TINYINT       NOT NULL,
  configSubscription  TINYINT       NOT NULL,
  accessModel         VARCHAR(10)   NOT NULL,
  payloadType         VARCHAR(100)  NULL,
  bodyXSLT            VARCHAR(100)  NULL,
  dataformXSLT        VARCHAR(100)  NULL,
  creator             VARCHAR(255) NOT NULL,
  description         VARCHAR(255)  NULL,
  language            VARCHAR(255)  NULL,
  name                VARCHAR(50)   NULL,
  replyPolicy         VARCHAR(15)   NULL,
  associationPolicy   VARCHAR(15)   NULL,
  maxLeafNodes        INTEGER       NULL,
  PRIMARY KEY (serviceID, nodeID)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPubsubNodeJIDs (
  serviceID           VARCHAR(100)  NOT NULL,
  nodeID              VARCHAR(100)  NOT NULL,
  jid                 VARCHAR(255)  NOT NULL,
  associationType     VARCHAR(20)   NOT NULL,
  PRIMARY KEY (serviceID, nodeID, jid(70))
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPubsubNodeGroups (
  serviceID           VARCHAR(100)  NOT NULL,
  nodeID              VARCHAR(100)  NOT NULL,
  rosterGroup         VARCHAR(100)   NOT NULL,
  INDEX ofPubsubNodeGroups_idx (serviceID, nodeID)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPubsubAffiliation (
  serviceID           VARCHAR(100)  NOT NULL,
  nodeID              VARCHAR(100)  NOT NULL,
  jid                 VARCHAR(255) NOT NULL,
  affiliation         VARCHAR(10)   NOT NULL,
  PRIMARY KEY (serviceID, nodeID, jid(70))
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPubsubItem (
  serviceID           VARCHAR(100)  NOT NULL,
  nodeID              VARCHAR(100)  NOT NULL,
  id                  VARCHAR(100)  NOT NULL,
  jid                 VARCHAR(255)  NOT NULL,
  creationDate        CHAR(15)      NOT NULL,
  payload             MEDIUMTEXT    NULL,
  PRIMARY KEY (serviceID, nodeID, id)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPubsubSubscription (
  serviceID           VARCHAR(100)  NOT NULL,
  nodeID              VARCHAR(100)  NOT NULL,
  id                  VARCHAR(100)  NOT NULL,
  jid                 VARCHAR(255) NOT NULL,
  owner               VARCHAR(255) NOT NULL,
  state               VARCHAR(15)   NOT NULL,
  deliver             TINYINT       NOT NULL,
  digest              TINYINT       NOT NULL,
  digest_frequency    INT           NOT NULL,
  expire              CHAR(15)      NULL,
  includeBody         TINYINT       NOT NULL,
  showValues          VARCHAR(30)   NULL,
  subscriptionType    VARCHAR(10)   NOT NULL,
  subscriptionDepth   TINYINT       NOT NULL,
  keyword             VARCHAR(200)  NULL,
  PRIMARY KEY (serviceID, nodeID, id)
)  DEFAULT CHARSET=utf8;

CREATE TABLE ofPubsubDefaultConf (
  serviceID           VARCHAR(100)  NOT NULL,
  leaf                TINYINT       NOT NULL,
  deliverPayloads     TINYINT       NOT NULL,
  maxPayloadSize      INTEGER       NOT NULL,
  persistItems        TINYINT       NOT NULL,
  maxItems            INTEGER       NOT NULL,
  notifyConfigChanges TINYINT       NOT NULL,
  notifyDelete        TINYINT       NOT NULL,
  notifyRetract       TINYINT       NOT NULL,
  presenceBased       TINYINT       NOT NULL,
  sendItemSubscribe   TINYINT       NOT NULL,
  publisherModel      VARCHAR(15)   NOT NULL,
  subscriptionEnabled TINYINT       NOT NULL,
  accessModel         VARCHAR(10)   NOT NULL,
  language            VARCHAR(255)  NULL,
  replyPolicy         VARCHAR(15)   NULL,
  associationPolicy   VARCHAR(15)   NOT NULL,
  maxLeafNodes        INTEGER       NOT NULL,
  PRIMARY KEY (serviceID, leaf)
)  DEFAULT CHARSET=utf8;


CREATE  TABLE rtCompany (
  id BIGINT NOT NULL AUTO_INCREMENT ,
  name VARCHAR(100) NOT NULL COMMENT '企业名称',
  shortName VARCHAR(45) NULL COMMENT '公司名称简称',
  englishName VARCHAR(100) NULL COMMENT '英文名称',
  pingying VARCHAR(45) NULL COMMENT '公司名称拼音',
  logo VARCHAR(255) COMMENT '公司logo',
  province VARCHAR(20) NULL COMMENT '省',
  city VARCHAR(20) NULL COMMENT '市',
  town VARCHAR(20) NULL COMMENT '镇区',
  email VARCHAR(45) NOT NULL COMMENT '电子邮件地址' ,
  address VARCHAR(100) NULL COMMENT '地址' ,
  fax VARCHAR(45) NULL COMMENT '传真号码' ,
  telephone VARCHAR(45) NULL COMMENT '电话号码' ,
  website VARCHAR(45) NULL COMMENT '企业门户网址' ,
  contact VARCHAR(20) NULL COMMENT '联系人',
  zipCode VARCHAR(20) NULL COMMENT '邮编',
  property VARCHAR(20) NULL COMMENT '公司性质',
  industry VARCHAR(20) NULL COMMENT '所属行业',
  description VARCHAR(1000) NULL COMMENT '广告词,或者简介' ,
  createDate DATETIME NOT NULL COMMENT '创建时间' ,
  PRIMARY KEY (id),
  UNIQUE KEY rtCompany_email (email)
)  AUTO_INCREMENT = 1000000 DEFAULT CHARSET=utf8 COMMENT = '企业' ;

CREATE  TABLE rtCompanyProperty (
  id BIGINT NOT NULL AUTO_INCREMENT ,
  companyId BIGINT NOT NULL DEFAULT 0,
  name VARCHAR(100) NULL ,
  propValue VARCHAR(2000) NULL,
  PRIMARY KEY (id) ,
  INDEX companyProperty_companyId_inx (companyId ASC)
);


CREATE TABLE rtConversationLog (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  senderJid varchar(45),
  senderNickName varchar(45) COMMENT '发送人昵称 ',
  sendTime datetime NOT NULL COMMENT '日志记录时间',
  receiverJid varchar(45) COMMENT '接收人JID',
  receiverNickName varchar(45) COMMENT '接收人昵称',
  messageText text NOT NULL COMMENT '消息正文',
  messageBytes varbinary(1000) COMMENT '消息原始内容',
  companyId bigint(20) default 0 COMMENT '所属分司',
  PRIMARY KEY (id),
  INDEX rtConversationLog_companyId_idx (companyId)
)  DEFAULT CHARSET=utf8 COMMENT='即时消息会话日志';

CREATE TABLE rtDepartment (
  id bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID	',
  name varchar(45) NOT NULL COMMENT '部门名称',
  seqNo int(11) COMMENT '显示顺序',
  remark varchar(45) COMMENT '部门简介',  
  parentId bigint(20) COMMENT '上级部门ID',
  coding varchar(200) COMMENT '节点编码，便于树节点运算。',
  companyId bigint(20) default 0 COMMENT '所属分司',
  level int(11) NOT NULL DEFAULT 0 COMMENT '级别',
  PRIMARY KEY (id),
  INDEX rtDepartment_companyId_idx (companyId)
)  DEFAULT CHARSET=utf8 COMMENT='部门';

CREATE TABLE rtEmployee (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  email varchar(45) COMMENT '电子邮件地址',
  fax varchar(45) COMMENT '传真号码',
  telephone varchar(45) COMMENT '办公电话号码',
  name varchar(45) NOT NULL COMMENT '姓名',
  telephoneExt varchar(45) COMMENT '办公电话分机号码,同是也是sip分机',
  mobile varchar(45) COMMENT '手机号码',
  departmentId bigint(20) DEFAULT 0 COMMENT '所属部门ID',
  birthday date COMMENT '出生日期',
  sex int(11) COMMENT '性别',
  username varchar(32) COMMENT '用户名',
  created datetime NOT NULL COMMENT '创建时间',
  updated datetime NOT NULL COMMENT '最近修改时间',
  birthplace varchar(45) COMMENT '籍贯，出生地。',
  password varchar(255),
  photo varchar(300) COMMENT '照片（大头像）路径',
  sipPass varchar(45) COMMENT 'SIP密码',
  photoBinval mediumtext COMMENT '编码后的照片，客户端使用',
  seqNo int(11) COMMENT '排序号',
  shortNo varchar(45) COMMENT '手机短号',
  pingying varchar(45) COMMENT '姓名拼音',
  position varchar(45) COMMENT '岗位ID',
  roleId bigint(20) NOT NULL  DEFAULT 0 COMMENT '用户角色id',
  companyId bigint(20)  DEFAULT 0 COMMENT '所属分司',
  isAdmin char(1) NOT NULL  default '0' COMMENT '是否是管理员' ,
  PRIMARY KEY (id),
  UNIQUE KEY username_UNIQUE (username),
  INDEX rtEmployee_companyId_idx (companyId),
  INDEX rtEmployee_departmentId_idx (departmentId)
)  DEFAULT CHARSET=utf8 COMMENT='员工';

CREATE TABLE IF NOT EXISTS rtDepartmentHide (
	 id BIGINT NOT NULL AUTO_INCREMENT COMMENT 'ID号',
     employeeId BIGINT NOT NULL DEFAULT 0 COMMENT '人员ID',
     departmentId BIGINT NOT NULL DEFAULT 0 COMMENT '部门ID',
	 hideDepartmentId BIGINT NOT NULL DEFAULT 0 NOT NULL COMMENT '隐藏部门的ID',
	 PRIMARY KEY (id),
	 INDEX rtDepartmentHide_employeeId_inx(employeeId),
	 INDEX rtDepartmentHide_hideDepartmentId_inx(departmentId)
) DEFAULT CHARSET=utf8 COMMENT '部门隐藏';

CREATE TABLE rtGroupConversationLog (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  senderId bigint(20) COMMENT '发送人账号',
  senderJid varchar(45),
  senderNickName varchar(45) NOT NULL COMMENT '发送人昵称',
  sendTime datetime NOT NULL COMMENT '日志记录时间',
  groupId bigint(20) NOT NULL COMMENT '接收人',
  groupJid varchar(45) COMMENT '接收人JID',
  groupName varchar(45) COMMENT '接收人昵称',
  messageText text NOT NULL COMMENT '消息正文',
  messageBytes varbinary(1000) COMMENT '消息原始内容',
  companyId bigint(20) default 0 COMMENT '所属分司',
  PRIMARY KEY (id),
  INDEX rtGroupConversationLog_companyId_idx (companyId)
)  DEFAULT CHARSET=utf8 COMMENT='即时消息会话日志';


CREATE TABLE rtMobileMemory (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  mobile varchar(45) NOT NULL COMMENT '手机号码',
  server varchar(45) NOT NULL COMMENT '落地语音交换机',
  local tinyint(1) NOT NULL COMMENT '是否本地号码',
  lastCallTime datetime NOT NULL COMMENT '最后拨打时间',
  PRIMARY KEY (id)
)  DEFAULT CHARSET=utf8 COMMENT='拨打手机的记忆';

CREATE TABLE rtRole (
  id bigint(20) NOT NULL AUTO_INCREMENT,
  name varchar(45) NOT NULL,
  remark varchar(45),
  companyId bigint(20) default 0 COMMENT '所属分司',
  PRIMARY KEY (id),
  INDEX rtRole_companyId_idx (companyId)
)  DEFAULT CHARSET=utf8 COMMENT='角色';

CREATE TABLE rtUserSetting (
  userName VARCHAR(45) NOT NULL ,
  sKey VARCHAR(45) NOT NULL ,
  sValue VARCHAR(45) NOT NULL ,
  companyId bigint(20) default 0 COMMENT '所属分司',
  PRIMARY KEY (userName, sKey,companyId) 
)  DEFAULT CHARSET=utf8 COMMENT = '用户设置';

CREATE  TABLE rtOfflineFile (
  sid VARCHAR(45) NOT NULL ,
  fileName VARCHAR(256) NOT NULL COMMENT '文件名称' ,
  fileSize BIGINT NOT NULL COMMENT '文件大小（K）' ,
  initiator VARCHAR(45) NOT NULL COMMENT '初始方JID' ,
  target VARCHAR(150) NOT NULL COMMENT '目标方JID' ,
  sendTime DATETIME NOT NULL COMMENT '发送时间' ,
  tag VARCHAR(45) NULL COMMENT '特殊标记',
  PRIMARY KEY (sid),
  INDEX rtOfflineFile_target_ind(target)
)  DEFAULT CHARSET=utf8 COMMENT = '离线文件' ;

CREATE TABLE rtDisplayPrice(
	id int not null AUTO_INCREMENT,
	name varchar(45) not null,
	area varchar(45),
	price varchar(45),
	primary key(id)
) DEFAULT CHARSET=utf8 comment='客户门户显示的价格';

ALTER TABLE ofVcard ADD signature varchar(100) COMMENT '个性签名';

# Finally, insert default table values.

INSERT INTO ofID (idType, id) VALUES (18, 1);
INSERT INTO ofID (idType, id) VALUES (19, 1);
INSERT INTO ofID (idType, id) VALUES (23, 1);
INSERT INTO ofID (idType, id) VALUES (26, 2);

INSERT INTO ofVersion (name, version) VALUES ('openfire', 22);

# Entry for default conference service
INSERT INTO ofMucService (serviceID, subdomain, isHidden) VALUES (1, 'conference', 0);


